@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ ImportImapSettingProgressPageTest::ImportImapSettingProgressPageTest(QObject *pa
     QStandardPaths::setTestModeEnabled(true);
 }
 
-ImportImapSettingProgressPageTest::~ImportImapSettingProgressPageTest()
-{
-}
+ImportImapSettingProgressPageTest::~ImportImapSettingProgressPageTest() = default;
 
 void ImportImapSettingProgressPageTest::shouldHaveDefaultValue()
 {
